@@ -1,7 +1,7 @@
 #!/bin/bash
 
 mkdir build && cd build
-cmake .. \
+cmake ${CMAKE_ARGS} .. \
     -GNinja \
     -DCMAKE_INSTALL_PREFIX=$PREFIX \
     -DCMAKE_PREFIX_PATH=$PREFIX \
